==> azureus_2.2.0.2.orig.tar.gz: azureus-2.2.0.2.orig/org/gudy/azureus2/ui/swing/UISwingImageRepository.java <==
/*
 * File    : UISwingImageRepository.java
 * Created : 31-Mar-2004
 * By      : parg
 * 
 * Azureus - a Java Bittorrent client
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.gudy.azureus2.ui.swing;

/**
 * @author parg
 *
 */

import java.io.*;
import java.awt.*;
import javax.swing.*;
import javax.imageio.*;

import org.gudy.azureus2.core3.util.Debug;
import org.gudy.azureus2.ui.common.*;

public class 
UISwingImageRepository 
{
	public static Image
	getImage(
		String		name )
	{
		try{
			return(ImageIO.read(UIImageRepository.getImageAsStream(name)));
			
		}catch( Throwable e ){
	
				// some versions of Opera don't have the imageio stuff available it seems
				// so catch all errors and return null
			
			Debug.printStackTrace( e );
			
			return( null );
		}
	}
	
	public static InputStream
	getImageAsStream(
		String		name )
	{
		return( UIImageRepository.getImageAsStream(name));
	}
	
	public static Image
	getImage(
		InputStream		is )
	{
		try{
			return(ImageIO.read(is));
			
		}catch( Throwable e ){
			
			Debug.printStackTrace( e );
			
			return( null );
		}	
	}
	
	public static Icon
	getIcon(
		String		name )
	{
		Image	image = getImage( name );
		
		return( image==null?null:new ImageIcon( image ));
	}
	
	public static Icon
	getIcon(
		InputStream		is )
	{
		Image	image = getImage( is );
		
		return( image==null?null:new ImageIcon( image ));
	}
}

==> azureus_4.3.0.6.orig.tar.gz: azureus-4.3.0.6/org/gudy/azureus2/ui/swing/UISwingImageRepository.java <==
/*
 * File    : UISwingImageRepository.java
 * Created : 31-Mar-2004
 * By      : parg
 * 
 * Azureus - a Java Bittorrent client
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details ( see the LICENSE file ).
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.gudy.azureus2.ui.swing;

/**
 * This class is used by the remote applet UI.
 * 
 * @author parg
 *
 */

import java.io.*;
import java.awt.*;
import javax.swing.*;
import javax.imageio.*;

import org.gudy.azureus2.ui.common.*;

public class 
UISwingImageRepository 
{
	public static Image
	getImage(
		String		name )
	{
		try{
			return(ImageIO.read(UIImageRepository.getImageAsStream(name)));
			
		}catch( Throwable e ){
	
				// some versions of Opera don't have the imageio stuff available it seems
				// so catch all errors and return null
			
			e.printStackTrace();
			
			return( null );
		}
	}
	
	public static InputStream
	getImageAsStream(
		String		name )
	{
		return( UIImageRepository.getImageAsStream(name));
	}
	
	public static Image
	getImage(
		InputStream		is )
	{
		try{
			return(ImageIO.read(is));
			
		}catch( Throwable e ){
			
			e.printStackTrace();
			
			return( null );
		}	
	}
	
	public static Icon
	getIcon(
		String		name )
	{
		Image	image = getImage( name );
		
		return( image==null?null:new ImageIcon( image ));
	}
	
	public static Icon
	getIcon(
		InputStream		is )
	{
		Image	image = getImage( is );
		
		return( image==null?null:new ImageIcon( image ));
	}
}
